Documentation
¶
Overview ¶
Package testspy implements a lightweight wrapper around testing.TB to assist in the testing of testing frameworks.
N.B. the spy does not the FailNow family of methods, as these would interfere with normal test execution. Instead, they panic if called.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExpectFail ¶
ExpectFail runs f with a spy TB and expects f to record failures.
func ExpectFatal ¶
ExpectFatal runs f with a spy TB and expects f to record a fatal failure.
func ExpectPass ¶
ExpectPass runs f with a spy TB and expects f to complete without recording any failures.
func RequireFail ¶
RequireFail runs f with a spy TB and requires f to record failures or else fails the test fatally.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.